# subpixel-edges

A pure Python implementation of the subpixel edge location algorithm from https://doi.org/10.1016/j.imavis.2012.10.005

The reference implementation can be found on from https://it.mathworks.com/matlabcentral/fileexchange/48908-accurate-subpixel-edge-location


# Installation

`pip install subpixel-edges`

## Development

```
git clone https://github.com/gravi-toni/subpixel-edges.git
pip install -e .
```

To run the tests (includes OpenCV):

`pip install -e .[tests]`

To run the examples (includes OpenCV):

`pip install -e .[examples]`
